@@ -40,8 +40,8 @@ impl SingleRenderState {
 impl super::SingleRenderState for SingleRenderState {
     fn interpolate(&self, other: &Self, r: f32) -> Self {
         Self {
-            transform: self.transform.interpolate_limit(&other.transform, r, 10.0),
-            size: self.size.interpolate_limit(&other.size, r, 0.5),
+            transform: self.transform.interpolate_limit(other.transform, r, 10.0),
+            size: self.size.interpolate_limit(other.size, r, 0.5),
             region: other.region,
         }
     }
